@@ -51,6 +51,8 @@ default_cp_tags <- list(
   category = list(ns = "cp", attrs = NA_character_)
 )
 
+
+#' @export
 `[<-.core_properties` <- function( x, i, j, value ){
   if( !i %in% x$data[,"name"] ) {
     attrs <- ifelse(is.na(default_cp_tags[[i]]$attrs), "", paste0(" ", default_cp_tags[[i]]$attrs))
@@ -61,10 +63,14 @@ default_cp_tags <- list(
   }
   x
 }
+
+
+#' @export
 `[.core_properties` <- function( x, i, j ){
   x$data[i,j]
 }
 
+
 write_core_properties <- function(core_matrix, package_dir){
   ns_ <- core_matrix$ns
   core_matrix <- core_matrix$data
@@ -88,3 +94,14 @@ write_core_properties <- function(core_matrix, package_dir){
   writeLines(enc2utf8(xml_), filename, useBytes=TRUE)
   invisible()
 }
+
+drop_templatenode_from_app <- function(package_dir){
+  file <- file.path(package_dir, "docProps", "app.xml")
+  if (!file.exists(file)) return()
+  doc <- read_xml(file)
+  node_template <- xml_child(doc, "d1:Template")
+  if (!inherits(node_template, "xml_missing")) {
+    xml_remove(node_template)
+    write_xml(doc, file)
+  }
+}
