@@ -3,7 +3,7 @@ xml_document_to_chrs <- function(xml_doc) {
   tf <- tempfile(fileext = ".xml")
   write_xml(xml_doc, options = c("format"), file = tf)
   # Read the XML file as a character vector
-  xml_str <- readLines(tf)
+  xml_str <- readLines(tf, warn = FALSE)
   xml_str <- gsub("^[[:blank:]]+", "", xml_str)
   # Prepend newlines to the XML string
   # where the opening tags are found
@@ -12,7 +12,7 @@ xml_document_to_chrs <- function(xml_doc) {
   # The following can be replaced with gregexpr()
   # but there is minor performance gain with the following
   writeLines(xml_str, tf, useBytes = TRUE)
-  xml_str <- readLines(tf)
+  xml_str <- readLines(tf, warn = FALSE)
 
   xml_str <- xml_str[xml_str != ""]
   xml_str
@@ -110,8 +110,9 @@ fix_img_refs_in_wml <- function(
   media_dir = "word/media",
   media_rel_dir = "media"
 ) {
-  has_match <- grepl("<a:blip r:embed=\"[^\"]+\"/>", xml_str) &
-    !grepl("<a:blip r:embed=\"rId[0-9]+\"/>", xml_str)
+  has_match <- grepl("<a:blip r:embed=\"[^\"]+\"", xml_str) &
+    !grepl("<a:blip r:embed=\"rId[0-9]+\"", xml_str)
+
   if (!any(has_match)) {
     return(xml_str)
   }
@@ -119,7 +120,7 @@ fix_img_refs_in_wml <- function(
   img_nodes_chr <- xml_str[has_match]
 
   path_values <- gsub(
-    "<a:blip r:embed=\"([^\"]+)\"/>",
+    "<a:blip r:embed=\"([^\"]+)\".*",
     "\\1",
     img_nodes_chr
   )
@@ -141,8 +142,8 @@ fix_img_refs_in_wml <- function(
     path <- path_table[[i, "path"]]
     rid <- path_table[[i, "id"]]
     xml_str <- gsub(
-      sprintf("<a:blip r:embed=\"%s\"/>", path),
-      sprintf("<a:blip r:embed=\"%s\"/>", rid),
+      sprintf("<a:blip r:embed=\"%s\"", path),
+      sprintf("<a:blip r:embed=\"%s\"", rid),
       xml_str,
       fixed = TRUE
     )
@@ -287,8 +288,7 @@ fix_hyperlink_refs_in_wml <- function(xml_str, doc_obj) {
   hyperlink_nodes_chr <- xml_str[has_match]
 
   hyperlink_values <- gsub(
-    "<w:hyperlink r:id=\"([^\"]+)\">",
-    "\\1",
+    ".*<w:hyperlink\\s+r:id=\"([^\"]+)\"[^>]*>.*", "\\1",
     hyperlink_nodes_chr
   )
   hyperlink_values <- unique(hyperlink_values)
@@ -308,8 +308,8 @@ fix_hyperlink_refs_in_wml <- function(xml_str, doc_obj) {
       target_mode = "External"
     )
     xml_str <- gsub(
-      sprintf("<w:hyperlink r:id=\"%s\">", url),
-      sprintf("<w:hyperlink r:id=\"%s\">", rid),
+      sprintf("<w:hyperlink r:id=\"%s\"", url),
+      sprintf("<w:hyperlink r:id=\"%s\"", rid),
       xml_str,
       fixed = TRUE
     )
@@ -338,7 +338,11 @@ convert_custom_styles_in_wml <- function(xml_str, styles) {
     return(xml_str)
   }
 
-  stylenames_types <- gsub("w:(pstlname|tstlname)=\"([^\"]+)\"", "\\1", stylenames)
+  stylenames_types <- gsub(
+    "w:(pstlname|tstlname)=\"([^\"]+)\"",
+    "\\1",
+    stylenames
+  )
   stylenames <- gsub("w:(pstlname|tstlname)=\"([^\"]+)\"", "\\2", stylenames)
 
   if (!all(stylenames %in% styles$style_name)) {
