@@ -5,7 +5,7 @@ x <- read_pptx()
 x <- add_slide(x, "Two Content")
 x <- phs_with(x,
   `Title 1` = "A title", # ph label
-  dt = "Jan. 26, 2025", # ph type
+  dt = Sys.Date(), # ph type
   `body[2]` = "Body 2", # ph type + type index
   left = "Left side", # ph keyword
   `6` = "Footer" # ph index
@@ -13,7 +13,7 @@ x <- phs_with(x,
 
 # reuse ph content via the .dots arg
 x <- read_pptx()
-my_ph_list <- list(`6` = "Footer", dt = "Jan. 26, 2025")
+my_ph_list <- list(`6` = "Footer", dt = Sys.Date())
 x <- add_slide(x, "Two Content")
 x <- phs_with(x, `Title 1` = "Title A", `body[2]` = "Body A", .dots = my_ph_list)
 x <- add_slide(x, "Two Content")
@@ -23,11 +23,9 @@ x <- phs_with(x, `Title 1` = "Title B", `body[2]` = "Body B", .dots = my_ph_list
 x <- read_pptx()
 x <- add_slide(x, "Two Content")
 x <- add_slide(x, "Two Content")
-x <- phs_with(x, `6` = "Footer", dt = "Jan. 26, 2025", .slide_idx = 1:2)
+x <- phs_with(x, `6` = "Footer", dt = Sys.Date(), .slide_idx = 1:2)
 
-# run to see results
+# run to open temp pptx file locally
 \dontrun{
-file <- tempfile(fileext = ".pptx")
-print(x, file)
-browseURL(file) # may not work on all systems
+print(x, preview = TRUE)
 }
