@@ -32,7 +32,7 @@ test_that("add image in docx", {
   }
 })
 
-pic <- file.path(R.home("doc"), "html", "logo.jpg" )
+pic <- file.path(R.home("doc"), "html", "logo.jpg")
 base_dir <- tempfile()
 file1 <- file.path(base_dir, "dir1", "logo1.jpg")
 file2 <- file.path(base_dir, "dir2", "logo1.jpg")
@@ -64,7 +64,7 @@ test_that("add multiple images in docx", {
 
 test_that("add image in pptx", {
   x <- read_pptx()
-  x <- add_slide(x)
+  x <- add_slide(x, "Title and Content")
   x <- ph_with(x, ext_img, location = ph_location_type())
   filename <- print(x, target = tempfile(fileext = ".pptx"))
 
@@ -75,7 +75,6 @@ test_that("add image in pptx", {
   subset_rel <- rel_df[grepl("^http://schemas(.*)image$", rel_df$type), ]
   expect_true(nrow(subset_rel) == 1)
   if (nrow(subset_rel) > 0) {
-
     node_blip <- xml_find_first(slide$get(), "//a:blip")
     expect_false(inherits(node_blip, "xml_missing"))
     expect_true(all(xml_attr(node_blip, "embed") %in% subset_rel$id))
@@ -85,16 +84,25 @@ test_that("add image in pptx", {
 
 test_that("add multiple images in pptx", {
   x <- read_pptx()
-  x <- add_slide(x)
-  x <- ph_with(x = x, value = external_img(src = file1),
-               location = ph_location(left = 0),
-               use_loc_size = FALSE)
-  x <- ph_with(x = x, value = external_img(src = file2),
-               location = ph_location(left = 3),
-               use_loc_size = FALSE)
-  x <- ph_with(x = x, value = external_img(src = file3),
-               location = ph_location(left = 6),
-               use_loc_size = FALSE)
+  x <- add_slide(x, "Title and Content")
+  x <- ph_with(
+    x = x,
+    value = external_img(src = file1),
+    location = ph_location(left = 0),
+    use_loc_size = FALSE
+  )
+  x <- ph_with(
+    x = x,
+    value = external_img(src = file2),
+    location = ph_location(left = 3),
+    use_loc_size = FALSE
+  )
+  x <- ph_with(
+    x = x,
+    value = external_img(src = file3),
+    location = ph_location(left = 6),
+    use_loc_size = FALSE
+  )
   pptx_file <- print(x, target = tempfile(fileext = ".pptx"))
 
   x <- read_pptx(path = pptx_file)
@@ -136,7 +144,7 @@ test_that("add svg in docx", {
 test_that("add svg in pptx", {
   skip_if_not_installed("rsvg")
   x <- read_pptx()
-  x <- add_slide(x)
+  x <- add_slide(x, "Title and Content")
   x <- ph_with(x, ext_svg, location = ph_location_type())
   filename <- print(x, target = tempfile(fileext = ".pptx"))
 
@@ -157,14 +165,13 @@ test_that("add svg in pptx", {
 })
 
 test_that("file size does not inflate with identical images", {
-  img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
+  img.file <- file.path(R.home("doc"), "html", "logo.jpg")
   doc <- read_docx()
-  doc <- body_add_img(x = doc, src = img.file, height = 1.06, width = 1.39 )
+  doc <- body_add_img(x = doc, src = img.file, height = 1.06, width = 1.39)
   file1 <- print(doc, target = tempfile(fileext = ".docx"))
   doc <- read_docx(path = file1)
   doc <- body_remove(doc)
-  doc <- body_add_img(x = doc, src = img.file, height = 1.06, width = 1.39 )
+  doc <- body_add_img(x = doc, src = img.file, height = 1.06, width = 1.39)
   file2 <- print(doc, target = tempfile(fileext = ".docx"))
   expect_equal(file.size(file1), file.size(file2), tolerance = 10)
 })
-
